<template>
  <view class="container">
    <!-- 头部 -->
    <view class="header">
      <view class="title">巡检项目明细</view>
      <view class="order-number">巡检单号: {{billNo}}</view>
    </view>

    <!-- 基本信息 -->
    <view class="section">
      <view class="section-header">基本信息</view>
      <view class="section-body">
        <view class="info-grid">
          <view class="info-item">
            <view class="info-label">项目名称</view>
            <view class="info-value">{{ formData.projName }}</view>
          </view>
          <view class="info-item" v-if="formData.itemMod">
            <view class="info-label">质量要求</view>
            <view class="info-value">{{ formData.itemMod }}</view>
          </view>
          <view class="info-item" v-if="formData.inspectionMethod">
            <view class="info-label">检验方法</view>
            <view class="info-value">{{ formData.inspectionMethod }}</view>
          </view>
          <view class="info-item" v-if="formData.usingInstruments">
            <view class="info-label">使用仪表</view>
            <view class="info-value">{{ formData.usingInstruments }}</view>
          </view>
          <view class="info-item">
            <view class="info-label">检验数</view>
            <view class="info-value">{{ formData.levelNum }}</view>
          </view>
          <view class="info-item" v-if="formData.minValue">
            <view class="info-label">下限</view>
            <view class="info-value">{{ formData.minValue }}</view>
          </view>
          <view class="info-item" v-if="formData.standardValue">
            <view class="info-label">标准值</view>
            <view class="info-value">{{ formData.standardValue }}</view>
          </view>
          <view class="info-item" v-if="formData.maxValue">
            <view class="info-label">上限</view>
            <view class="info-value">{{ formData.maxValue }}</view>
          </view>
          <view class="info-item" v-if="formData.updater">
            <view class="info-label">更新人</view>
            <view class="info-value">{{ formData.updater }}</view>
          </view>
          <view class="info-item" v-if="formData.updateTime">
            <view class="info-label">更新时间</view>
            <view class="info-value">{{ formData.updateTime }}</view>
          </view>
        </view>
      </view>
    </view>

    <!-- 检验结果 -->
    <view class="section">
      <view class="section-header">检验结果</view>
      <view class="section-body">
        <view class="info-grid">
          <view class="info-item" v-if="formData.result">
            <view class="info-label">预览结果</view>
            <view class="info-value">{{formData.result}}</view>
          </view>
        </view>

        <view v-if="formData.result != null" class="result-preview">
          <view class="info-label">预览结果</view>
          <view class="info-value">{{formData.result}}</view>
        </view>

        <view v-if="formData.remarks != null" class="result-ng">
          <view class="info-label">不合格描述</view>
          <view class="info-value danger">{{formData.remarks}}</view>
        </view>
      </view>
    </view>

    <!-- 结果录入 -->
    <view class="section">
      <view class="section-header">检验结果录入</view>
      <view class="section-body">
        <view class="inspection-hint">
          <view class="hint-text">没有最大值和最小值时填写0（未通过检验）或1（通过检验）</view>
        </view>
        <view class="input-group">
          <view class="input-wrapper">
            <input v-if="tableData.length < formData.levelNum"
              v-model="formData.fcheckResu"
              type="number"
              class="result-input"
              placeholder="请输入检验结果"
              placeholder-class="placeholder" />
            <button v-if="(tableData.length < formData.levelNum)"
              style="margin: 0px;background-color: #3498db;color:#ffffff ;" class="btn primary-btn"
              @click="submit">保存结果</button>
          </view>
        </view>
      </view>
    </view>

    <!-- 图片预览 -->
    <view v-if="isShowImg" class="section">
      <view class="section-header">相关图片</view>
      <view class="section-body">
        <view class="image-preview" @click="previewImage">
          <image :src="base64Image" mode="aspectFit" class="preview-image"/>
        </view>
      </view>
    </view>
    <!-- 结果表格 -->
    <view v-if="tableData.length > 0" class="table-container">
      <view class="table-header">
        <view class="th">编号</view>
        <view class="th">检验结果<i style="color: rgb(0 212 68);"
            v-if="!(tableData.length < formData.levelNum)">(输入已完成)</i></view>
        <view class="th">操作</view>
      </view>

      <view v-for="(item, index) in tableData" :key="index" class="table-row">
        <view class="td">{{ index + 1 }}</view>
        <view class="td">
          <view :class="['result-badge', item.fstand === '√' ? 'OK' : 'NG']">
            {{ item.fcheckResu }}
          </view>
        </view>
        <view class="td">
          <button v-if="!isNumber" class="btn danger-btn" @click="numberEdit(item)">
            {{ editResult(item.fcheckResu) }}
          </button>
          <button v-if="isNumber" class="btn danger-btn" @click="toDetail(item)">
            修改
          </button>
        </view>
      </view>
    </view>

    <!-- 操作按钮 -->
    <view class="action-buttons">
      <button class="action-btn warning" @click="saveRemarks">添加不合格描述</button>
    </view>

    <!-- 修改不合格描述弹出框 -->
    <view v-if="remarksPopup" class="overlay">
      <view class="popup">
        <view class="popup-header">
          <h3>修改不合格描述</h3>
        </view>
        <view class="popup-content">
          <view class="input-group">
            <view class="input-label">不合格描述：</view>
            <input class="input-field" type="text" v-model="remarks" placeholder="请输入不合格描述"/>
          </view>
        </view>
        <view class="popup-actions">
          <button class="action-btn primary" @click="editRemarks">修改</button>
          <button class="action-btn secondary" @click="remarksPopup = !remarksPopup">取消</button>
        </view>
      </view>
    </view>

    <!-- 修改检验结果弹出框 -->
    <view v-if="showPopup" class="overlay">
      <view class="popup">
        <view class="popup-header">
          <h3>修改检验结果</h3>
        </view>
        <view class="popup-content">
          <view class="input-group">
            <view class="input-label">检验结果：</view>
            <input class="input-field" type="text" v-model="editData.fcheckResu" placeholder="请输入检验结果"/>
          </view>
        </view>
        <view class="popup-actions">
          <button class="action-btn primary" @click="eidt">修改</button>
          <button class="action-btn secondary" @click="showPopup = !showPopup">取消</button>
        </view>
      </view>
    </view>
  </view>
</template>

<script>
export default {
  data() {
    return {
      formData: {},
      isNumber: false,
      checkItem: "",
      id: 0,
      gid: 0,
      billNo: "",
      showPopup: false,
      editData: {},
      tableData: [],
      isShowImg: false,
      base64Image:"",
      remarks: "",
      remarksPopup: false,
    }
  },
  methods: {
    getResultClass(result) {
      if (result === '合格') return 'result-pass';
      if (result === '不合格') return 'result-fail';
      return 'result-pending';
    },
    

    previewImage() {
      uni.previewImage({
        urls: [this.base64Image],
      });
    },
    editResult(fcheckResu) {
      if (fcheckResu == '1') {
        return "改为不合格";
      } else {
        return "改为合格";
      }
    },
    submit() {

      let count = this.formData.levelNum;
      let fstand = "√";

      //有最大值和最小值就根据是否符合标准值更新判定结果，没有最大值和最小值就根据是否通过检验判定结果
      if (this.formData.maxValue && this.formData.minValue) {

        if (!this.formData.fcheckResu) {
          this.$showMessage("请输入检验值");
          return;
        }

        if (this.formData.fcheckResu >= this.formData.minValue && this.formData.fcheckResu <= this.formData
            .maxValue) {
          fstand = "√"
        } else {
          fstand = "×";
        }
        count = 1;
      } else {

        if (!this.formData.fcheckResu) {
          this.formData.fcheckResu = 1
        }

        if (this.formData.fcheckResu == 0 || this.formData.fcheckResu == 1) {
          this.formData.isPass = this.formData.fcheckResu
        } else {
          this.$showMessage("无标准值时，检验结果只能为0或1!");
          return;
        }
        count = count - this.tableData.length;
      }

      this.formData.updater = this.$loginInfo.account;

      this.$post({
        url: "/XJ/SetQSItemDetail",
        data: {
          pid: this.id,
          gid: this.gid,
          fstand: fstand,
          fcheckResu: this.formData.fcheckResu,
          updateBy: this.formData.updater,
          count: count
        }
      }).then(res => {
        this.formData.fcheckResu = null;
        this.$showMessage("保存成功");
        this.refreshResult();
      })

    },
    refreshResult() {
      this.$post({
        url: "/XJ/getXjDetail02ById",
        data: {
          id: this.id
        }
      }).then(res => {
        this.formData = res.data.tbBillList.itemXj01;

        this.tableData = res.data.tbBillList.itemXj02s;

        if (this.formData.imageData) {
          this.isShowImg = true;
          this.base64Image = 'data:image/jpeg;base64,' + this.formData.imageData;
        }

        if (this.formData.maxValue && this.formData.minValue && this.formData.standardValue) {
          this.isNumber = true;
        }
      })
    },
    toDetail(item) {
      this.showPopup = !this.showPopup;
      this.editData = item;
    },
    eidt() {

      if (!this.editData.fcheckResu) {
        this.$showMessage("请输入检验结果");
      }

      if (this.formData.fcheckResu == this.editData.fcheckResu) {
        this.$showMessage("修改成功");
        return;
      }

      let fstand = "√";

      if (this.formData.maxValue && this.formData.minValue) {

        if (!this.editData.fcheckResu) {
          this.$showMessage("请输入检验值");
          return;
        }

        if (this.editData.fcheckResu >= this.formData.minValue && this.editData.fcheckResu <= this.formData
            .maxValue) {
          this.editData.isPass = 1
        } else {
          this.editData.isPass = 0
          fstand = "×";
        }
      } else {

        if (!this.editData.fcheckResu) {
          this.editData.fcheckResu = 1
        }

        if (this.editData.fcheckResu == 0 || this.editData.fcheckResu == 1) {
          if (this.editData.fcheckResu == 0) {
            fstand = "×";
          }
        } else {
          this.$showMessage("无标准值时，检验结果只能为0或1!");
          return;
        }
      }

      this.editData.updater = this.$loginInfo.account;

      this.$post({
        url: "/XJ/UpdateQSItemDetail",
        data: {
          id: this.editData.id,
          pid: this.id,
          gid: this.gid,
          fstand: fstand,
          fcheckResu: this.editData.fcheckResu,
          updateBy: this.editData.updater,
        }
      }).then(res => {
        this.showPopup = !this.showPopup;
        this.$showMessage("修改成功");
        this.refreshResult(); //刷新页面
      })
    },
    numberEdit(item) {

      let fstand = "√";
      let fcheckResu = 1;

      if (item.fcheckResu == '1') {
        fstand = "×";
        fcheckResu = 0;
      }

      this.$post({
        url: "/XJ/UpdateQSItemDetail",
        data: {
          id: item.id,
          pid: item.pid,
          gid: item.gid,
          fstand: fstand,
          fcheckResu: fcheckResu,
          updateBy: this.$loginInfo.account,
        }
      }).then(res => {
        this.$showMessage("修改成功");
        this.refreshResult(); //刷新页面
      })
    },
    saveRemarks() {
      this.remarksPopup = !this.remarksPopup;
      this.remarks = this.formData.remarks;
    },
    editRemarks() {
      if (this.remarks) {
        //saveRemarksGid
        this.$post({
          url: "/XJ/saveRemarksPid",
          data: {
            pid: this.formData.id,
            remarks: this.remarks
          }
        }).then(res => {
          if (res.data.tbBillList > 0) {
            this.formData.remarks = this.remarks;
            this.remarksPopup = !this.remarksPopup;
            this.$showMessage("保存成功");
          }
        })
      }
    }
  },
  onLoad(options) {
    //options中包含了url附带的参数
    let params = options;

    this.id = params["id"];
    this.billNo = params["billNo"];
    this.gid = params["gid"];

    this.refreshResult();
  }
}
</script>

<style scoped>
/* 基础样式 */
.container {
  padding: 10px;
  background-color: #f5f7fa;
  min-height: 100vh;
}

/* 头部样式 */
.header {
  background-color: white;
  padding: 20px;
  border-radius: 8px;
  box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
  margin-bottom: 20px;
}

.title {
  font-size: 20px;
  font-weight: 600;
  color: #2c3e50;
  margin-bottom: 8px;
}

.order-number {
  font-size: 14px;
  color: #3498db;
  font-weight: 500;
}

/* 区域样式 */
.section {
  background-color: white;
  border-radius: 8px;
  box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
  margin-bottom: 20px;
  overflow: hidden;
}

.section-header {
  background-color: #f8f9fa;
  padding: 15px 20px;
  border-bottom: 1px solid #eee;
  font-size: 16px;
  font-weight: 600;
  color: #2c3e50;
}

.section-body {
  padding: 20px;
}

/* 信息网格 */
.info-grid {
  display: grid;
  grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
  gap: 15px;
}

.info-item {
  display: flex;
  flex-direction: column;
  gap: 5px;
}

.info-label {
  font-size: 12px;
  color: #7f8c8d;
  font-weight: 500;
}

.info-value {
  font-size: 14px;
  color: #2c3e50;
}

.info-value.danger {
  color: #e74c3c;
  font-weight: 500;
}

/* 结果忽章 */
.result-badge {
  padding: 4px 8px;
  border-radius: 4px;
  font-size: 12px;
  font-weight: 500;
  display: inline-block;
  width: fit-content;
}

.result-badge.OK {
  background-color: #d4edda;
  color: #155724;
}

.result-badge.NG {
  background-color: #f8d7da;
  color: #721c24;
}

/* 检验输入区 */
.inspection-hint {
  background-color: #fff3cd;
  padding: 10px;
  border-radius: 4px;
  margin-bottom: 15px;
}

.hint-text {
  font-size: 12px;
  color: #856404;
}

.input-group {
  display: flex;
  align-items: center;
  margin-bottom: 15px;
}

.input-wrapper {
  display: flex;
  gap: 12px;
  width: 100%;
}

.result-input {
  flex: 1;
  padding: 8px 12px;
  border: 1px solid #ddd;
  border-radius: 4px;
  font-size: 14px;
  background-color: white;
}

.btn {
  padding: 8px 16px;
  border: none;
  border-radius: 4px;
  font-size: 14px;
  cursor: pointer;
  transition: all 0.2s;
}

.btn.primary-btn {
  background-color: #3498db;
  color: white;
}

.btn.danger-btn {
  background-color: #e74c3c;
  color: white;
}

/* 图片预览 */
.image-preview {
  text-align: center;
  cursor: pointer;
}

.preview-image {
  max-width: 100%;
  max-height: 300px;
  border-radius: 4px;
  border: 1px solid #ddd;
}

/* 结果预览 */
.result-preview {
  margin: 16px 0;
  padding: 12px;
  background-color: #f8f9fa;
  border-radius: 4px;
  display: flex;
  align-items: center;
  gap: 12px;
}

.result-ng {
  margin: 16px 0;
  padding: 12px;
  background-color: #f8d7da;
  border-radius: 4px;
  display: flex;
  align-items: center;
  gap: 12px;
}

/* 表格容器 */
.table-container {
  border: 1px solid #ddd;
  border-radius: 4px;
  margin-top: 20px;
  overflow: hidden;
}

.table-header {
  display: flex;
  background-color: #3498db;
  color: white;
}

.th {
  flex: 1;
  padding: 12px;
  font-weight: bold;
  text-align: center;
}

.table-row {
  display: flex;
  border-bottom: 1px solid #eee;
  padding: 12px;
}

.table-row:last-child {
  border-bottom: none;
}

.td {
  flex: 1;
  display: flex;
  align-items: center;
  justify-content: center;
}

/* 操作按钮 */
.action-buttons {
  display: flex;
  flex-direction: column;
  gap: 10px;
  margin-bottom: 20px;
}

.action-btn {
  padding: 12px 20px;
  border: none;
  border-radius: 6px;
  font-size: 14px;
  font-weight: 500;
  cursor: pointer;
  transition: all 0.2s;
}

.action-btn.primary {
  background-color: #3498db;
  color: white;
}

.action-btn.secondary {
  background-color: #95a5a6;
  color: white;
}

.action-btn.warning {
  background-color: #f39c12;
  color: white;
}

/* 弹出框样式 */
.overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.5);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 1000;
}

.popup {
  background-color: white;
  border-radius: 8px;
  box-shadow: 0 4px 20px rgba(0, 0, 0, 0.15);
  width: 90%;
  max-width: 400px;
  max-height: 80vh;
  overflow-y: auto;
}

.popup-header {
  padding: 20px;
  border-bottom: 1px solid #eee;
}

.popup-header h3 {
  font-size: 18px;
  font-weight: 600;
  color: #2c3e50;
  margin: 0;
}

.popup-content {
  padding: 20px;
}

.input-group {
  display: flex;
  flex-direction: column;
  gap: 8px;
}

.input-label {
  font-size: 14px;
  color: #7f8c8d;
  font-weight: 500;
}

.input-field {
  padding: 8px 12px;
  border: 1px solid #ddd;
  border-radius: 4px;
  font-size: 14px;
  background-color: white;
}

.popup-actions {
  padding: 20px;
  border-top: 1px solid #eee;
  display: flex;
  gap: 10px;
  justify-content: flex-end;
}

/* 响应式设计 */
@media (max-width: 768px) {
  .info-grid {
    grid-template-columns: 1fr;
  }
  
  .input-wrapper {
    flex-direction: column;
  }
  
  .table-row {
    flex-direction: column;
    text-align: center;
  }
  
  .td {
    justify-content: center;
    margin-bottom: 8px;
  }
}
</style>